<?php

namespace Dipendra\Programming\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Dipendra\Programming\Interfaces\CourseRepositoryInterface;
use Dipendra\Programming\Repositories\Presenter\CourseItemTransformer;

/**
 * Pubic API controller class.
 */
class CoursePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Dipendra\Course\Interfaces\CourseRepositoryInterface $course
     *
     * @return type
     */
    public function __construct(CourseRepositoryInterface $course)
    {
        $this->repository = $course;
        parent::__construct();
    }

    /**
     * Show course's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $courses = $this->repository
            ->setPresenter('\\Dipendra\\Programming\\Repositories\\Presenter\\CourseListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $courses['code'] = 2000;
        return response()->json($courses)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show course.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $course = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($course)) {
            $course         = $this->itemPresenter($module, new CourseItemTransformer);
            $course['code'] = 2001;
            return response()->json($course)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
