<?php

namespace Dipendra\Programming\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Dipendra\Programming\Interfaces\TutorialRepositoryInterface;
use Dipendra\Programming\Repositories\Presenter\TutorialItemTransformer;

/**
 * Pubic API controller class.
 */
class TutorialPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Dipendra\Tutorial\Interfaces\TutorialRepositoryInterface $tutorial
     *
     * @return type
     */
    public function __construct(TutorialRepositoryInterface $tutorial)
    {
        $this->repository = $tutorial;
        parent::__construct();
    }

    /**
     * Show tutorial's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $tutorials = $this->repository
            ->setPresenter('\\Dipendra\\Programming\\Repositories\\Presenter\\TutorialListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $tutorials['code'] = 2000;
        return response()->json($tutorials)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show tutorial.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $tutorial = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($tutorial)) {
            $tutorial         = $this->itemPresenter($module, new TutorialItemTransformer);
            $tutorial['code'] = 2001;
            return response()->json($tutorial)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
