<?php

namespace Dipendra\Programming\Http\Controllers;
use Litepie\Programming\Http\Requests\ChapterRequest;
use Litepie\Programming\Models\Chapter;

trait ChapterWorkflow {
	
    /**
     * Workflow controller function for chapter.
     *
     * @param Model   $chapter
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ChapterRequest $request, Chapter $chapter, $step)
    {

        try {

            $chapter->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('programming::chapter.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/chapter/chapter/' . $chapter->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/chapter/chapter/' . $chapter->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for chapter.
     *
     * @param Model   $chapter
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Chapter $chapter, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $chapter->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('programming::chapter.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.chapter.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.chapter.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.chapter.message', $data)->render();

        }

    }
}