<?php

namespace Dipendra\Programming\Http\Controllers;
use Litepie\Programming\Http\Requests\CourseRequest;
use Litepie\Programming\Models\Course;

trait CourseWorkflow {
	
    /**
     * Workflow controller function for course.
     *
     * @param Model   $course
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CourseRequest $request, Course $course, $step)
    {

        try {

            $course->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('programming::course.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/course/course/' . $course->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/course/course/' . $course->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for course.
     *
     * @param Model   $course
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Course $course, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $course->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('programming::course.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.course.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.course.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('programming::admin.course.message', $data)->render();

        }

    }
}