<?php

namespace Dipendra\Programming\Policies;

use App\User;
use Dipendra\Programming\Models\Chapter;

class ChapterPolicy
{

    /**
     * Determine if the given user can view the chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function view(User $user, Chapter $chapter)
    {
        if ($user->canDo('programming.chapter.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $chapter->user_id;
    }

    /**
     * Determine if the given user can create a chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('programming.chapter.create');
    }

    /**
     * Determine if the given user can update the given chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function update(User $user, Chapter $chapter)
    {
        if ($user->canDo('programming.chapter.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $chapter->user_id;
    }

    /**
     * Determine if the given user can delete the given chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function destroy(User $user, Chapter $chapter)
    {
        if ($user->canDo('programming.chapter.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $chapter->user_id;
    }

    /**
     * Determine if the given user can verify the given chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function verify(User $user, Chapter $chapter)
    {
        if ($user->canDo('programming.chapter.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('programming.chapter.verify') 
        && $user->is('manager')
        && $chapter->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given chapter.
     *
     * @param User $user
     * @param Chapter $chapter
     *
     * @return bool
     */
    public function approve(User $user, Chapter $chapter)
    {
        if ($user->canDo('programming.chapter.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
