<?php

namespace Dipendra\Programming\Policies;

use App\User;
use Dipendra\Programming\Models\Course;

class CoursePolicy
{

    /**
     * Determine if the given user can view the course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function view(User $user, Course $course)
    {
        if ($user->canDo('programming.course.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $course->user_id;
    }

    /**
     * Determine if the given user can create a course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('programming.course.create');
    }

    /**
     * Determine if the given user can update the given course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function update(User $user, Course $course)
    {
        if ($user->canDo('programming.course.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $course->user_id;
    }

    /**
     * Determine if the given user can delete the given course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function destroy(User $user, Course $course)
    {
        if ($user->canDo('programming.course.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $course->user_id;
    }

    /**
     * Determine if the given user can verify the given course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function verify(User $user, Course $course)
    {
        if ($user->canDo('programming.course.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('programming.course.verify') 
        && $user->is('manager')
        && $course->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given course.
     *
     * @param User $user
     * @param Course $course
     *
     * @return bool
     */
    public function approve(User $user, Course $course)
    {
        if ($user->canDo('programming.course.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
