<?php

namespace Dipendra\Programming\Policies;

use App\User;
use Dipendra\Programming\Models\Tutorial;

class TutorialPolicy
{

    /**
     * Determine if the given user can view the tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function view(User $user, Tutorial $tutorial)
    {
        if ($user->canDo('programming.tutorial.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tutorial->user_id;
    }

    /**
     * Determine if the given user can create a tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('programming.tutorial.create');
    }

    /**
     * Determine if the given user can update the given tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function update(User $user, Tutorial $tutorial)
    {
        if ($user->canDo('programming.tutorial.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tutorial->user_id;
    }

    /**
     * Determine if the given user can delete the given tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function destroy(User $user, Tutorial $tutorial)
    {
        if ($user->canDo('programming.tutorial.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tutorial->user_id;
    }

    /**
     * Determine if the given user can verify the given tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function verify(User $user, Tutorial $tutorial)
    {
        if ($user->canDo('programming.tutorial.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('programming.tutorial.verify') 
        && $user->is('manager')
        && $tutorial->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tutorial.
     *
     * @param User $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function approve(User $user, Tutorial $tutorial)
    {
        if ($user->canDo('programming.tutorial.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
