<?php

namespace Dipendra\Programming\Providers;

use Illuminate\Support\ServiceProvider;

class ProgrammingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'programming');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'programming');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('programming', function ($app) {
            return $this->app->make('Dipendra\Programming\Programming');
        });

// Bind Course to repository
        $this->app->bind(
            \Dipendra\Programming\Interfaces\CourseRepositoryInterface::class,
            \Dipendra\Programming\Repositories\Eloquent\CourseRepository::class
        );
        // Bind Chapter to repository
        $this->app->bind(
            \Dipendra\Programming\Interfaces\ChapterRepositoryInterface::class,
            \Dipendra\Programming\Repositories\Eloquent\ChapterRepository::class
        );
        // Bind Tutorial to repository
        $this->app->bind(
            \Dipendra\Programming\Interfaces\TutorialRepositoryInterface::class,
            \Dipendra\Programming\Repositories\Eloquent\TutorialRepository::class
        );

        $this->app->register(\Dipendra\Programming\Providers\AuthServiceProvider::class);
        $this->app->register(\Dipendra\Programming\Providers\EventServiceProvider::class);
        $this->app->register(\Dipendra\Programming\Providers\RouteServiceProvider::class);
        // $this->app->register(\Dipendra\Programming\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['programming'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('dipendra/programming.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/programming')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/programming')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
