<?php

namespace Dipendra\Programming\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Course validator
        \Dipendra\Programming\Models\Course::class => \Dipendra\Programming\Workflow\CourseValidator::class,

        // Bind Chapter validator
        \Dipendra\Programming\Models\Chapter::class => \Dipendra\Programming\Workflow\ChapterValidator::class,

        // Bind Tutorial validator
        \Dipendra\Programming\Models\Tutorial::class => \Dipendra\Programming\Workflow\TutorialValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Course actions
        \Dipendra\Programming\Models\Course::class => \Dipendra\Programming\Workflow\CourseAction::class,

        // Bind Chapter actions
        \Dipendra\Programming\Models\Chapter::class => \Dipendra\Programming\Workflow\ChapterAction::class,

        // Bind Tutorial actions
        \Dipendra\Programming\Models\Tutorial::class => \Dipendra\Programming\Workflow\TutorialAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Course notifiers
        \Dipendra\Programming\Models\Course::class => \Dipendra\Programming\Workflow\CourseNotifier::class,

        // Bind Chapter notifiers
        \Dipendra\Programming\Models\Chapter::class => \Dipendra\Programming\Workflow\ChapterNotifier::class,

        // Bind Tutorial notifiers
        \Dipendra\Programming\Models\Tutorial::class => \Dipendra\Programming\Workflow\TutorialNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
