<?php

namespace Dipendra\Programming\Workflow;

use Dipendra\Programming\Models\Chapter;
use Validator;

class ChapterValidator
{

    /**
     * Determine if the given chapter is valid for complete status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function complete(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given chapter is valid for verify status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function verify(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given chapter is valid for approve status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function approve(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given chapter is valid for publish status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function publish(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given chapter is valid for archive status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function archive(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given chapter is valid for unpublish status.
     *
     * @param Chapter $chapter
     *
     * @return bool / Validator
     */
    public function unpublish(Chapter $chapter)
    {
        return Validator::make($chapter->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
