<?php

namespace Dipendra\Programming\Workflow;

use Dipendra\Programming\Models\Course;
use Validator;

class CourseValidator
{

    /**
     * Determine if the given course is valid for complete status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function complete(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given course is valid for verify status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function verify(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given course is valid for approve status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function approve(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given course is valid for publish status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function publish(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given course is valid for archive status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function archive(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given course is valid for unpublish status.
     *
     * @param Course $course
     *
     * @return bool / Validator
     */
    public function unpublish(Course $course)
    {
        return Validator::make($course->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
